==> prestashop_1.4.0.2.zip: prestashop/modules/secuvad/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{secuvad}prestashop>secuvad_980755daf8a750c0b0f50a735ad57048'] = 'Módulo Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_781ba313b90fbc22ddea8b3bf0a6cc4d'] = 'Solución de lucha contra el fraude en línea';
$_MODULE['<{secuvad}prestashop>secuvad_d6f47e627cb8b9186caa435aba1c32ae'] = '¿Está seguro de querer suprimir este módulo?';
$_MODULE['<{secuvad}prestashop>secuvad_307bfa08da823ee566ce867b563eb223'] = 'Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_8fbc70c37e2deff790fe4e95fce7c9d8'] = 'Para utilizar el módulo Secuvad, configúrelo.';
$_MODULE['<{secuvad}prestashop>secuvad_d3dd6e2937eb4430278bce947553b7ca'] = 'Estado Secuvad:';
$_MODULE['<{secuvad}prestashop>secuvad_163f6b2856a83d0bb03aee72f8f072a5'] = 'Impago transmitido';
$_MODULE['<{secuvad}prestashop>secuvad_f3182252d448607de30d2b4cfe420db1'] = 'Actualizar el estado Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_af7fdbd69d96ddaba932d48c45b89dcf'] = 'Transmitir un impago';
$_MODULE['<{secuvad}prestashop>secuvad_719728eb242d3fff6ba18a8b4733e1e4'] = 'Atención, al transmitir este impago a SECUVAD, implica que su crédito es REAL, EFECTIVA y EXIGIBLE y que autoriza de manera EXCLUSIVA a SECUVAD el cobro del mismo. ¿Desea continuar?';
$_MODULE['<{secuvad}prestashop>secuvad_85b94c96da82beb688084f64adfbf185'] = 'Configuración Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_04d45d9f5ece926babe251d7b628ecca'] = 'El archivo PaymentCC no está presente, por favor oipie este archivo en la carpeta Classes/ de PrestaShop.';
$_MODULE['<{secuvad}prestashop>secuvad_2113b53bbb4a93786e042937cd04f21f'] = 'Por favor configure todas las asociaciones';
$_MODULE['<{secuvad}prestashop>secuvad_062f3f5ae8644882a2da949705ced1ac'] = 'Si ya tiene una cuenta';
$_MODULE['<{secuvad}prestashop>secuvad_0e79ca3a8ef61f2ec317e5734082de3f'] = 'Tipo de empresa no válido';
$_MODULE['<{secuvad}prestashop>secuvad_73c23113d237a4f8e56df46745d9e08e'] = 'Nombre de la empresa no válido';
$_MODULE['<{secuvad}prestashop>secuvad_a5253c7f1e4f48d55eb46507f9af21e3'] = 'Capital no válido';
$_MODULE['<{secuvad}prestashop>secuvad_c99b7e43f604b6c71a06336b727d99b9'] = 'URL de su sitio Web no válida';
$_MODULE['<{secuvad}prestashop>secuvad_5b550fbcefc1b473adff36761fbc97fd'] = 'Dirección no válida';
$_MODULE['<{secuvad}prestashop>secuvad_c52850b57fd20ba633bd49a98fe65ef0'] = 'Código postal no válido';
$_MODULE['<{secuvad}prestashop>secuvad_ceb8e9adca824ee71883fce1612e9fea'] = 'Ciudad no válida';
$_MODULE['<{secuvad}prestashop>secuvad_3f1e50fba8ee7cc383eb164c7d5d0fb9'] = 'País no válido';
$_MODULE['<{secuvad}prestashop>secuvad_c678a6253de57c93c0ab007d23a119c6'] = 'CRS no válido';
$_MODULE['<{secuvad}prestashop>secuvad_b5061793e15ec84cd10f3b299d1f51a2'] = 'Siren no válido';
$_MODULE['<{secuvad}prestashop>secuvad_4c84a0aa246d1439ee5beafedf0e7a74'] = 'Debe seleccionar al menos una categoría';
$_MODULE['<{secuvad}prestashop>secuvad_f711de88101c1207804945493429bc6e'] = 'Tratamiento no válido';
$_MODULE['<{secuvad}prestashop>secuvad_9bd987e611b01bc320c4b41fd0f44cb0'] = 'Apellido no válido';
$_MODULE['<{secuvad}prestashop>secuvad_d4a7da3641038f3a960339e8880297e4'] = 'Nombre no válido';
$_MODULE['<{secuvad}prestashop>secuvad_166fb3fab9011cc55bad2971f0a63af0'] = 'Función no válida';
$_MODULE['<{secuvad}prestashop>secuvad_d9a821ab8ae9651b6e4a11798bb4fd39'] = 'Email no válido';
$_MODULE['<{secuvad}prestashop>secuvad_7f203a223defb75e34e9949e9054511a'] = 'Teléfono no válido';
$_MODULE['<{secuvad}prestashop>secuvad_a6f2a48726b0d36107e00e20795d3d37'] = 'Login no válido';
$_MODULE['<{secuvad}prestashop>secuvad_cba0b206627d45fbf0ae707e20d4a38f'] = 'Contraseña no válida';
$_MODULE['<{secuvad}prestashop>secuvad_12477418db51dc813000335f72b9fcf2'] = 'Modo no válido';
$_MODULE['<{secuvad}prestashop>secuvad_c1c8a564c10a0efe07bb4e4b20d88cc9'] = 'ID no válido';
$_MODULE['<{secuvad}prestashop>secuvad_7ccf58c950043c9fbfed668df13ce608'] = 'Parámetros actualizados';
$_MODULE['<{secuvad}prestashop>secuvad_e6fb0f75b2ebc0b761b583df95f3fa76'] = 'Error durante la actualización';
$_MODULE['<{secuvad}prestashop>secuvad_1c76cbfe21c6f44c1d1e59d54f3e4420'] = 'Empresa';
$_MODULE['<{secuvad}prestashop>secuvad_051672911a3f1f05efba78a553ef6fe2'] = 'Login:';
$_MODULE['<{secuvad}prestashop>secuvad_b341a59d5636ed3d6a819137495b08a0'] = 'Contraseña:';
$_MODULE['<{secuvad}prestashop>secuvad_1ee1c44c2dc81681f961235604247b81'] = 'Modo:';
$_MODULE['<{secuvad}prestashop>secuvad_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{secuvad}prestashop>secuvad_756d97bb256b8580d4d71ee0c547804e'] = 'Producción';
$_MODULE['<{secuvad}prestashop>secuvad_e0f0b0564d3d29a93fad7a4178b7b1ca'] = 'ID:';
$_MODULE['<{secuvad}prestashop>secuvad_94966d90747b97d1f0f206c98a8b1ac3'] = 'Enviar';
$_MODULE['<{secuvad}prestashop>secuvad_8cf04a9734132302f96da8e113e80ce5'] = 'Inicio';
$_MODULE['<{secuvad}prestashop>secuvad_201095b8aa27cc3bd5e6dcc407ab2bdb'] = 'Categorías Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_49ee3087348e8d44e1feda1917443987'] = 'Nombre';
$_MODULE['<{secuvad}prestashop>secuvad_116b7a3c4f415260f5a0d9a9d3a49f97'] = 'Categoría Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_d66b57a9d6f7bff70d7dad7d0ac30018'] = 'Pago Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_593bda837f8ae222993fc189457c92a0'] = 'Tipo de pago';
$_MODULE['<{secuvad}prestashop>secuvad_01ae2e552c349bd5608af0f670f8ebc2'] = 'Desconocido';
$_MODULE['<{secuvad}prestashop>secuvad_df5e109fb5e06f7aff5f18958ed53aeb'] = 'Transportista Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_68eb4e159f449c625edb23b2c35e7259'] = 'Transportista Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_7cc72fb5b56d882a4c34cb68dd4604aa'] = 'Plazos Transportista Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_869a67c555b83bb3abfbbca6abdd84a9'] = 'Para activar su módulo Secuvad, rellene el formulario y pulse en \"Guardar\', y después en \"Enviar\"';
$_MODULE['<{secuvad}prestashop>secuvad_6bf36964a57a5eaa5f46504ca9882cdb'] = 'Tipo de empresa';
$_MODULE['<{secuvad}prestashop>secuvad_c700e3beca05135eca91df55981402f5'] = 'SARL';
$_MODULE['<{secuvad}prestashop>secuvad_3dd6b9265ff18f31dc30df59304b0ca7'] = 'SA';
$_MODULE['<{secuvad}prestashop>secuvad_e00147cd1ed977d431491ce5c1b02f8a'] = 'EURL';
$_MODULE['<{secuvad}prestashop>secuvad_2db46c628cfb3bd1545d3b5a14b4a9c5'] = 'SAS';
$_MODULE['<{secuvad}prestashop>secuvad_d3cc996e019ec9721479e63b2fd622d8'] = 'Empresa individual';
$_MODULE['<{secuvad}prestashop>secuvad_57aab2fcd93938cfbca356bb5571b25b'] = 'SNC';
$_MODULE['<{secuvad}prestashop>secuvad_5e116ceb48a98fb755f22df7ea1e2396'] = 'Nombre de la empresa:';
$_MODULE['<{secuvad}prestashop>secuvad_7b1b1d6f1a6793e17aeeffa80ac8fdaa'] = 'Capital:';
$_MODULE['<{secuvad}prestashop>secuvad_e5cb8489f57db7c15eed3258e48cd5f3'] = 'Sitio:';
$_MODULE['<{secuvad}prestashop>secuvad_2bf1d5fae1c321d594fdedf05058f709'] = 'Dirección:';
$_MODULE['<{secuvad}prestashop>secuvad_da67a6777d9e5451375f8ab27e15af8b'] = 'Código postal:';
$_MODULE['<{secuvad}prestashop>secuvad_bffb711ec36f280459d11dce315da72f'] = 'Ciudad:';
$_MODULE['<{secuvad}prestashop>secuvad_f64be5eef68442a8f50cf535b92ad3e4'] = 'País:';
$_MODULE['<{secuvad}prestashop>secuvad_51bdf131ea9fab11d517cc19fe5d8d73'] = 'RCS:';
$_MODULE['<{secuvad}prestashop>secuvad_f4e462b9ed48a0e96da9730875f9dd58'] = 'Siren:';
$_MODULE['<{secuvad}prestashop>secuvad_70397c4b252a5168c5ec003931cea215'] = 'Campos necesarios';
$_MODULE['<{secuvad}prestashop>secuvad_0e0f3e0ad86de8103ac0f5c74726da24'] = 'Tipo de productos';
$_MODULE['<{secuvad}prestashop>secuvad_432d0563f8721b5285e5bd18c0aee4ea'] = 'Categorías de sus productos:';
$_MODULE['<{secuvad}prestashop>secuvad_7d0ba2d2a3223badb6f7b026946fc16d'] = 'Contacto en la empresa';
$_MODULE['<{secuvad}prestashop>secuvad_6e4dd233509432e2f00cdfae01b8f9ac'] = 'Tratamiento:';
$_MODULE['<{secuvad}prestashop>secuvad_2c9b5b15a6d3cc951ca57c65e4966fd3'] = 'Señor';
$_MODULE['<{secuvad}prestashop>secuvad_7f2a1b59ac1ab6d2d892dbbf4f132c40'] = 'Señora:';
$_MODULE['<{secuvad}prestashop>secuvad_be5e0b5d50d48b049bd0f7b57cd163f9'] = 'Apellido:';
$_MODULE['<{secuvad}prestashop>secuvad_668a8d8d7ffe5da112b266e46b79b685'] = 'Nombre:';
$_MODULE['<{secuvad}prestashop>secuvad_6a858980896cb9daee81930c61bc1696'] = 'Función:';
$_MODULE['<{secuvad}prestashop>secuvad_01401fe9a93df81d28637e5218597b76'] = 'Email:';
$_MODULE['<{secuvad}prestashop>secuvad_673ae02fffb72f0fe68a66f096a01347'] = 'Teléfono:';
$_MODULE['<{secuvad}prestashop>secuvad_7dce122004969d56ae2e0245cb754d35'] = 'Modificar';
$_MODULE['<{secuvad}prestashop>secuvad_0ba7583639a274c434bbe6ef797115a4'] = 'Guardar';
$_MODULE['<{secuvad}prestashop>secuvad_2f8531293ddfd4f30bb978e93d49f650'] = 'Email:';
$_MODULE['<{secuvad}prestashop>secuvad_42dbbc555675ff22f80115c0570de888'] = 'Descripción del problema:';
$_MODULE['<{secuvad}prestashop>secuvad_401886eb11224f37cbbd93211e991c85'] = 'Archivos de log:';
$_MODULE['<{secuvad}prestashop>secuvad_fa29ad39f28d8d3a9b873ac37dec2899'] = 'Informe de error';
$_MODULE['<{secuvad}prestashop>secuvad_7d806d0a6feb01a9e865e20656705bb1'] = 'Los siguientes módulos de pago no están asociados:';
$_MODULE['<{secuvad}prestashop>secuvad_8f761a4b3b9d772f765cb33cb2393229'] = 'Los siguientes métodos de transportista no están asociados:';
$_MODULE['<{secuvad}prestashop>secuvad_4959707e32a840b214a456f2049e9f4a'] = 'Las siguientes categorías no están asociadas:';
$_MODULE['<{secuvad}prestashop>secuvad_b07c890926c9672d17f948b4e5cf2bf2'] = 'Error durante la activación';
$_MODULE['<{secuvad}prestashop>secuvad_902b0d55fddef6f8d651fe1035b7d4bd'] = 'Error';
$_MODULE['<{secuvad}prestashop>secuvad_6a41f4e014a17adf3d6cdd7a20a628f2'] = 'Imposible remitirse al fraude ';
$_MODULE['<{secuvad}prestashop>secuvad_2e92ae79ff32b37fee4368a594792183'] = 'Error de conexión';
$_MODULE['<{secuvad}prestashop>secuvad_2d7839314eb05f8988381b70dbc1548b'] = 'No es un fraude';
$_MODULE['<{secuvad}prestashop>secuvad_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{secuvad}prestashop>secuvad_1b93ce75458ea0ce94250a781ff0835e'] = 'Es un fraude';
$_MODULE['<{secuvad}prestashop>secuvad_93cba07454f06a4a960172bbd6e2a435'] = 'Sí';
$_MODULE['<{secuvad}prestashop>secuvad_830560d945b2aa75e58b6f0b7ffe0882'] = 'No sometido a Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_e77d1c075ac8442c061e9b97c1be30e1'] = 'Validado por SECUVAD';
$_MODULE['<{secuvad}prestashop>secuvad_f611e08cffb261d08d536dc0b3e3cce3'] = 'En curso de valoración por Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_a464f32e0e54df4786e7d905577b7f0c'] = 'Invalidado por Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_f6ba219e7a45632ab4d39822108d68f3'] = 'A valorar por el cliente';
$_MODULE['<{secuvad}prestashop>secuvad_09b107c04bba6b19e1a8bf0a2e1fe1d0'] = 'A valorar por SECUVAD';
$_MODULE['<{secuvad}prestashop>secuvad_config_8bcaf785d6c5771e3c49bd90e0885c2a'] = 'Intento de pirateo';
$_MODULE['<{secuvad}prestashop>secuvad_config_1f4eee5122ff1dfb7c7ff3aa8e879222'] = 'Acceso no autorizado';
$_MODULE['<{secuvad}prestashop>secuvad_config_07d92e6fcc22058f4b93f02a29e8d9f9'] = 'Los datos enviados son:';

==> prestashop_1.4.0.3.zip: prestashop/modules/secuvad/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{secuvad}prestashop>secuvad_980755daf8a750c0b0f50a735ad57048'] = 'Módulo Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_781ba313b90fbc22ddea8b3bf0a6cc4d'] = 'Solución de lucha contra el fraude en línea';
$_MODULE['<{secuvad}prestashop>secuvad_d6f47e627cb8b9186caa435aba1c32ae'] = '¿Está seguro de querer suprimir este módulo?';
$_MODULE['<{secuvad}prestashop>secuvad_307bfa08da823ee566ce867b563eb223'] = 'Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_8fbc70c37e2deff790fe4e95fce7c9d8'] = 'Para utilizar el módulo Secuvad, configúrelo.';
$_MODULE['<{secuvad}prestashop>secuvad_d3dd6e2937eb4430278bce947553b7ca'] = 'Estado Secuvad:';
$_MODULE['<{secuvad}prestashop>secuvad_163f6b2856a83d0bb03aee72f8f072a5'] = 'Impago transmitido';
$_MODULE['<{secuvad}prestashop>secuvad_f3182252d448607de30d2b4cfe420db1'] = 'Actualizar el estado Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_af7fdbd69d96ddaba932d48c45b89dcf'] = 'Transmitir un impago';
$_MODULE['<{secuvad}prestashop>secuvad_719728eb242d3fff6ba18a8b4733e1e4'] = 'Atención, al transmitir este impago a SECUVAD, implica que su crédito es REAL, EFECTIVA y EXIGIBLE y que autoriza de manera EXCLUSIVA a SECUVAD el cobro del mismo. ¿Desea continuar?';
$_MODULE['<{secuvad}prestashop>secuvad_85b94c96da82beb688084f64adfbf185'] = 'Configuración Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_04d45d9f5ece926babe251d7b628ecca'] = 'El archivo PaymentCC no está presente, por favor oipie este archivo en la carpeta Classes/ de PrestaShop.';
$_MODULE['<{secuvad}prestashop>secuvad_2113b53bbb4a93786e042937cd04f21f'] = 'Por favor configure todas las asociaciones';
$_MODULE['<{secuvad}prestashop>secuvad_062f3f5ae8644882a2da949705ced1ac'] = 'Si ya tiene una cuenta';
$_MODULE['<{secuvad}prestashop>secuvad_0e79ca3a8ef61f2ec317e5734082de3f'] = 'Tipo de empresa no válido';
$_MODULE['<{secuvad}prestashop>secuvad_73c23113d237a4f8e56df46745d9e08e'] = 'Nombre de la empresa no válido';
$_MODULE['<{secuvad}prestashop>secuvad_a5253c7f1e4f48d55eb46507f9af21e3'] = 'Capital no válido';
$_MODULE['<{secuvad}prestashop>secuvad_c99b7e43f604b6c71a06336b727d99b9'] = 'URL de su sitio Web no válida';
$_MODULE['<{secuvad}prestashop>secuvad_5b550fbcefc1b473adff36761fbc97fd'] = 'Dirección no válida';
$_MODULE['<{secuvad}prestashop>secuvad_c52850b57fd20ba633bd49a98fe65ef0'] = 'Código postal no válido';
$_MODULE['<{secuvad}prestashop>secuvad_ceb8e9adca824ee71883fce1612e9fea'] = 'Ciudad no válida';
$_MODULE['<{secuvad}prestashop>secuvad_3f1e50fba8ee7cc383eb164c7d5d0fb9'] = 'País no válido';
$_MODULE['<{secuvad}prestashop>secuvad_c678a6253de57c93c0ab007d23a119c6'] = 'CRS no válido';
$_MODULE['<{secuvad}prestashop>secuvad_b5061793e15ec84cd10f3b299d1f51a2'] = 'Siren no válido';
$_MODULE['<{secuvad}prestashop>secuvad_4c84a0aa246d1439ee5beafedf0e7a74'] = 'Debe seleccionar al menos una categoría';
$_MODULE['<{secuvad}prestashop>secuvad_f711de88101c1207804945493429bc6e'] = 'Tratamiento no válido';
$_MODULE['<{secuvad}prestashop>secuvad_9bd987e611b01bc320c4b41fd0f44cb0'] = 'Apellido no válido';
$_MODULE['<{secuvad}prestashop>secuvad_d4a7da3641038f3a960339e8880297e4'] = 'Nombre no válido';
$_MODULE['<{secuvad}prestashop>secuvad_166fb3fab9011cc55bad2971f0a63af0'] = 'Función no válida';
$_MODULE['<{secuvad}prestashop>secuvad_d9a821ab8ae9651b6e4a11798bb4fd39'] = 'Email no válido';
$_MODULE['<{secuvad}prestashop>secuvad_7f203a223defb75e34e9949e9054511a'] = 'Teléfono no válido';
$_MODULE['<{secuvad}prestashop>secuvad_a6f2a48726b0d36107e00e20795d3d37'] = 'Login no válido';
$_MODULE['<{secuvad}prestashop>secuvad_cba0b206627d45fbf0ae707e20d4a38f'] = 'Contraseña no válida';
$_MODULE['<{secuvad}prestashop>secuvad_12477418db51dc813000335f72b9fcf2'] = 'Modo no válido';
$_MODULE['<{secuvad}prestashop>secuvad_c1c8a564c10a0efe07bb4e4b20d88cc9'] = 'ID no válido';
$_MODULE['<{secuvad}prestashop>secuvad_7ccf58c950043c9fbfed668df13ce608'] = 'Parámetros actualizados';
$_MODULE['<{secuvad}prestashop>secuvad_e6fb0f75b2ebc0b761b583df95f3fa76'] = 'Error durante la actualización';
$_MODULE['<{secuvad}prestashop>secuvad_1c76cbfe21c6f44c1d1e59d54f3e4420'] = 'Empresa';
$_MODULE['<{secuvad}prestashop>secuvad_051672911a3f1f05efba78a553ef6fe2'] = 'Login:';
$_MODULE['<{secuvad}prestashop>secuvad_b341a59d5636ed3d6a819137495b08a0'] = 'Contraseña:';
$_MODULE['<{secuvad}prestashop>secuvad_1ee1c44c2dc81681f961235604247b81'] = 'Modo:';
$_MODULE['<{secuvad}prestashop>secuvad_0cbc6611f5540bd0809a388dc95a615b'] = 'Test';
$_MODULE['<{secuvad}prestashop>secuvad_756d97bb256b8580d4d71ee0c547804e'] = 'Producción';
$_MODULE['<{secuvad}prestashop>secuvad_e0f0b0564d3d29a93fad7a4178b7b1ca'] = 'ID:';
$_MODULE['<{secuvad}prestashop>secuvad_94966d90747b97d1f0f206c98a8b1ac3'] = 'Enviar';
$_MODULE['<{secuvad}prestashop>secuvad_8cf04a9734132302f96da8e113e80ce5'] = 'Inicio';
$_MODULE['<{secuvad}prestashop>secuvad_201095b8aa27cc3bd5e6dcc407ab2bdb'] = 'Categorías Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_49ee3087348e8d44e1feda1917443987'] = 'Nombre';
$_MODULE['<{secuvad}prestashop>secuvad_116b7a3c4f415260f5a0d9a9d3a49f97'] = 'Categoría Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_d66b57a9d6f7bff70d7dad7d0ac30018'] = 'Pago Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_593bda837f8ae222993fc189457c92a0'] = 'Tipo de pago';
$_MODULE['<{secuvad}prestashop>secuvad_01ae2e552c349bd5608af0f670f8ebc2'] = 'Desconocido';
$_MODULE['<{secuvad}prestashop>secuvad_df5e109fb5e06f7aff5f18958ed53aeb'] = 'Transportista Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_68eb4e159f449c625edb23b2c35e7259'] = 'Transportista Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_7cc72fb5b56d882a4c34cb68dd4604aa'] = 'Plazos Transportista Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_869a67c555b83bb3abfbbca6abdd84a9'] = 'Para activar su módulo Secuvad, rellene el formulario y pulse en \"Guardar\', y después en \"Enviar\"';
$_MODULE['<{secuvad}prestashop>secuvad_6bf36964a57a5eaa5f46504ca9882cdb'] = 'Tipo de empresa';
$_MODULE['<{secuvad}prestashop>secuvad_c700e3beca05135eca91df55981402f5'] = 'SARL';
$_MODULE['<{secuvad}prestashop>secuvad_3dd6b9265ff18f31dc30df59304b0ca7'] = 'SA';
$_MODULE['<{secuvad}prestashop>secuvad_e00147cd1ed977d431491ce5c1b02f8a'] = 'EURL';
$_MODULE['<{secuvad}prestashop>secuvad_2db46c628cfb3bd1545d3b5a14b4a9c5'] = 'SAS';
$_MODULE['<{secuvad}prestashop>secuvad_d3cc996e019ec9721479e63b2fd622d8'] = 'Empresa individual';
$_MODULE['<{secuvad}prestashop>secuvad_57aab2fcd93938cfbca356bb5571b25b'] = 'SNC';
$_MODULE['<{secuvad}prestashop>secuvad_5e116ceb48a98fb755f22df7ea1e2396'] = 'Nombre de la empresa:';
$_MODULE['<{secuvad}prestashop>secuvad_7b1b1d6f1a6793e17aeeffa80ac8fdaa'] = 'Capital:';
$_MODULE['<{secuvad}prestashop>secuvad_e5cb8489f57db7c15eed3258e48cd5f3'] = 'Sitio:';
$_MODULE['<{secuvad}prestashop>secuvad_2bf1d5fae1c321d594fdedf05058f709'] = 'Dirección:';
$_MODULE['<{secuvad}prestashop>secuvad_da67a6777d9e5451375f8ab27e15af8b'] = 'Código postal:';
$_MODULE['<{secuvad}prestashop>secuvad_bffb711ec36f280459d11dce315da72f'] = 'Ciudad:';
$_MODULE['<{secuvad}prestashop>secuvad_f64be5eef68442a8f50cf535b92ad3e4'] = 'País:';
$_MODULE['<{secuvad}prestashop>secuvad_51bdf131ea9fab11d517cc19fe5d8d73'] = 'RCS:';
$_MODULE['<{secuvad}prestashop>secuvad_f4e462b9ed48a0e96da9730875f9dd58'] = 'Siren:';
$_MODULE['<{secuvad}prestashop>secuvad_70397c4b252a5168c5ec003931cea215'] = 'Campos necesarios';
$_MODULE['<{secuvad}prestashop>secuvad_0e0f3e0ad86de8103ac0f5c74726da24'] = 'Tipo de productos';
$_MODULE['<{secuvad}prestashop>secuvad_432d0563f8721b5285e5bd18c0aee4ea'] = 'Categorías de sus productos:';
$_MODULE['<{secuvad}prestashop>secuvad_7d0ba2d2a3223badb6f7b026946fc16d'] = 'Contacto en la empresa';
$_MODULE['<{secuvad}prestashop>secuvad_6e4dd233509432e2f00cdfae01b8f9ac'] = 'Tratamiento:';
$_MODULE['<{secuvad}prestashop>secuvad_2c9b5b15a6d3cc951ca57c65e4966fd3'] = 'Señor';
$_MODULE['<{secuvad}prestashop>secuvad_7f2a1b59ac1ab6d2d892dbbf4f132c40'] = 'Señora';
$_MODULE['<{secuvad}prestashop>secuvad_be5e0b5d50d48b049bd0f7b57cd163f9'] = 'Apellido:';
$_MODULE['<{secuvad}prestashop>secuvad_668a8d8d7ffe5da112b266e46b79b685'] = 'Nombre:';
$_MODULE['<{secuvad}prestashop>secuvad_6a858980896cb9daee81930c61bc1696'] = 'Función:';
$_MODULE['<{secuvad}prestashop>secuvad_01401fe9a93df81d28637e5218597b76'] = 'Email:';
$_MODULE['<{secuvad}prestashop>secuvad_673ae02fffb72f0fe68a66f096a01347'] = 'Teléfono:';
$_MODULE['<{secuvad}prestashop>secuvad_7dce122004969d56ae2e0245cb754d35'] = 'Modificar';
$_MODULE['<{secuvad}prestashop>secuvad_0ba7583639a274c434bbe6ef797115a4'] = 'Guardar';
$_MODULE['<{secuvad}prestashop>secuvad_2f8531293ddfd4f30bb978e93d49f650'] = 'Email:';
$_MODULE['<{secuvad}prestashop>secuvad_42dbbc555675ff22f80115c0570de888'] = 'Descripción del problema:';
$_MODULE['<{secuvad}prestashop>secuvad_401886eb11224f37cbbd93211e991c85'] = 'Archivos de log:';
$_MODULE['<{secuvad}prestashop>secuvad_fa29ad39f28d8d3a9b873ac37dec2899'] = 'Informe de error';
$_MODULE['<{secuvad}prestashop>secuvad_7d806d0a6feb01a9e865e20656705bb1'] = 'Los siguientes módulos de pago no están asociados:';
$_MODULE['<{secuvad}prestashop>secuvad_8f761a4b3b9d772f765cb33cb2393229'] = 'Los siguientes métodos de transportista no están asociados:';
$_MODULE['<{secuvad}prestashop>secuvad_4959707e32a840b214a456f2049e9f4a'] = 'Las siguientes categorías no están asociadas:';
$_MODULE['<{secuvad}prestashop>secuvad_b07c890926c9672d17f948b4e5cf2bf2'] = 'Error durante la activación';
$_MODULE['<{secuvad}prestashop>secuvad_902b0d55fddef6f8d651fe1035b7d4bd'] = 'Error';
$_MODULE['<{secuvad}prestashop>secuvad_6a41f4e014a17adf3d6cdd7a20a628f2'] = 'Imposible remitirse al fraude ';
$_MODULE['<{secuvad}prestashop>secuvad_2e92ae79ff32b37fee4368a594792183'] = 'Error de conexión';
$_MODULE['<{secuvad}prestashop>secuvad_2d7839314eb05f8988381b70dbc1548b'] = 'No es un fraude';
$_MODULE['<{secuvad}prestashop>secuvad_bafd7322c6e97d25b6299b5d6fe8920b'] = 'No';
$_MODULE['<{secuvad}prestashop>secuvad_1b93ce75458ea0ce94250a781ff0835e'] = 'Es un fraude';
$_MODULE['<{secuvad}prestashop>secuvad_93cba07454f06a4a960172bbd6e2a435'] = 'Sí';
$_MODULE['<{secuvad}prestashop>secuvad_830560d945b2aa75e58b6f0b7ffe0882'] = 'No sometido a Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_e77d1c075ac8442c061e9b97c1be30e1'] = 'Validado por SECUVAD';
$_MODULE['<{secuvad}prestashop>secuvad_f611e08cffb261d08d536dc0b3e3cce3'] = 'En curso de valoración por Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_a464f32e0e54df4786e7d905577b7f0c'] = 'Invalidado por Secuvad';
$_MODULE['<{secuvad}prestashop>secuvad_f6ba219e7a45632ab4d39822108d68f3'] = 'A valorar por el cliente';
$_MODULE['<{secuvad}prestashop>secuvad_09b107c04bba6b19e1a8bf0a2e1fe1d0'] = 'A valorar por SECUVAD';
$_MODULE['<{secuvad}prestashop>secuvad_config_8bcaf785d6c5771e3c49bd90e0885c2a'] = 'Intento de pirateo';
$_MODULE['<{secuvad}prestashop>secuvad_config_1f4eee5122ff1dfb7c7ff3aa8e879222'] = 'Acceso no autorizado';
$_MODULE['<{secuvad}prestashop>secuvad_config_07d92e6fcc22058f4b93f02a29e8d9f9'] = 'Los datos enviados son:';
